Sftpd.IODevice (Sftpd v0.1.1)

Copy Markdown View Source

GenServer that manages SFTP file handles.

Reads use backend range callbacks when available. Writes are persisted to a local temp file immediately and optionally mirrored to backend streaming callbacks for lower memory usage on large transfers.

Summary

Functions

Returns a specification to start this module under a supervisor.

Start an IODevice process (not linked to caller).

Types

mode()

@type mode() :: :read | :write

read_strategy()

@type read_strategy() :: :range | :buffered

write_strategy()

@type write_strategy() :: :legacy | :streaming | :streaming_replay

Functions

child_spec(init_arg)

Returns a specification to start this module under a supervisor.

See Supervisor.

start(opts)

@spec start(map()) :: GenServer.on_start()

Start an IODevice process (not linked to caller).