GenServer that manages SFTP file handles.
Reads use backend range callbacks when available. Writes are persisted to a local temp file immediately and optionally mirrored to backend streaming callbacks for lower memory usage on large transfers.
Summary
Functions
Returns a specification to start this module under a supervisor.
Start an IODevice process (not linked to caller).
Types
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
@spec start(map()) :: GenServer.on_start()
Start an IODevice process (not linked to caller).